import { getDescendantClassName, getModifierClassName, normalizeClassName } from '../helper';
class BaseHeadlessComponent {
    constructor(sc) {
        this.sc = sc;
    }
    getDescendantOfParent() {
        return '';
    }
    getParentComponentName() {
        return '';
    }
    /**
     * Component's class names which will be scoped
     */
    getClassNames() {
        const classNames = [this.getComponentName()];
        const descendantOfParent = this.getDescendantOfParent();
        const parentComponentName = this.getParentComponentName();
        if (descendantOfParent && parentComponentName) {
            classNames.push(getDescendantClassName(parentComponentName, descendantOfParent));
        }
        return classNames;
    }
    /**
     * Other class names which won't be scoped
     */
    getExtraClassNames() {
        const { className } = this.sc;
        return className ? normalizeClassName(className).split(' ') : [];
    }
    getDescendantClassName(descendant) {
        return getDescendantClassName(this.getComponentName(), descendant);
    }
    getModifierClassName(modifier) {
        return getModifierClassName(this.getComponentName(), modifier);
    }
    getStateClassName(state, prefix = 'is') {
        return `${prefix}-${state}`;
    }
}
export { BaseHeadlessComponent };
